\name{makePMG}
\alias{makePMG}
\title{Function to create a data package containing graphs}
\description{
  Given a Bioconductor data packages, this function creates a data
  package containing PubMed co-citation graphs with nodes being
  specified ids and edges linking two nodes that were co-cited by papers
  abstracted by NLM
}
\usage{
makePMG(pkgName, pkgPath, author, version)
}
\arguments{
  \item{pkgName}{\code{pkgName} a character string for the name of a
    Bioconductor data package}
  \item{pkgPath}{\code{pkgPath} a character string for the path where
    the newly created package will be stored. A new directory with the
    name of the data package appended by "graph" will be created in the path}
  \item{author}{\code{author} a list with two elements. name - a
    character string for the name of the maintainer of the new package
    and address - the email address of the maintainer}
  \item{version}{\code{version} a character string for the version
    number of the package to be created}
}
\details{
  This function is applicaple to all Bioconductor data packages. For
  non-Bioconductor packages, the data package should have environments
  pkgNamePMID, pkgNamePMID2PROBE, pkgNameSYMBOL, and pkgNameLOCUSID. The
  function then creates a data package named pkgNamegraph that contains
  three graph objects with PROBE, SYMBOL, and LOCUSID as ids for nodes.
}
\value{
  This function does not return any value
}
\references{\url{http://wwww.ncbi.nlm.nih.gov/PubMed/}}
\author{Jianhua Zhang}
\note{This function is part of the Bioconductor project at Dana-Farber
  Cancer Institute to provide Bioinformatics functionalities through R}
\seealso{\code{\link{makePubMedGraph}}}
\examples{
if(interactive()){
    if(require("hgu95av2")){
        makePMG("hgu95av2", tempdir(), list(name = "yourName", address =
        "yourEMail"), "yourVersion")
    }else{
        stop("Data package unavailable")
    }
}
}
\keyword{manip}

\eof
\name{makePubMedGraph}
\alias{makePubMedGraph}
\title{ Make a Graph object based on PubMed links }
\description{
  makePubMedGraph creates a graph object with links based on PubMed ids.  
  Currently, the possible node types for the new graph are genename, 
  affyid, and locusid.
}
\usage{
makePubMedGraph(nodeType, lib)
}

\arguments{
  \item{nodeType}{ a character string that tells what the node types are }
  \item{lib}{ the library that contains the environments that will be 
              used to create the graph object }
}
\details{
  Currently, the only nodeTypes available are affyid, locusid, and genename.
  A key of "NotMapped" in reverse environments represents NA.
}
\value{
  A graph object with links based on PubMed ids will be returned.
}

\author{ Elizabeth Whalen }

\seealso{\code{\link{makeGraph}}, \code{\link{graph}} }

\examples{

}
\keyword{ manip }


\eof
\name{revList}
\alias{revList}
\title{ Reverses a List of Lists }
\description{
  revList creates a new list where the names of the new list are the 
values in the original list and the values in new list are the names 
in the original list.  Thus, revList creates a new list that is the 
reverse mapping of the original list, oList.  For values that were 
originally NA, the new key is "NotMapped". 
}
\usage{
revList(V, L)
}

\arguments{
  \item{V}{ the names of the new list (the values from the original list) }
  \item{L}{ the original list to be reversed }
}
\value{
  A list of lists that has the key and value pairs reversed from the 
original list parameter.
}
\author{ Elizabeth Whalen }

\seealso{ \code{\link{reverseEnv}}, \code{\link{uniqueVec}} }

\examples{

}
\keyword{ list }






\eof
\name{reverseEnv}
\alias{reverseEnv}

\title{ Reverse Environments }
\description{ reverseEnv reverses the key and value pairs of an
 environment so the original values become the new keys and the 
 original keys become the new values.  Any original values of 
 NA will be replaced by "NotMapped" as the new key.
}
\usage{
reverseEnv(lib, envir)
}

\arguments{
  \item{lib}{ character string of the library's name where the original 
              environment is stored }
  \item{envir}{ the environment to be reversed }
}

\value{ a new environment will be returned with key and values switched 
        from the original environment.
}

\author{Elizabeth Whalen }

\seealso{\code{\link{revList}}, \code{\link{uniqueVec}} }

\examples{

# works but very slow
# PMID2AFFY<-reverseEnv("hgu95a",hgu95aPMID)

}
\keyword{ data }





\eof
\name{uniqueVec}
\alias{uniqueVec}
\title{Find the unique elements of a vector or list and return those.  }
\description{
  The difference between this and \code{\link{unique}} is that the list
  is vectorized and the argument \code{removeNA} allows you to
  optionally remove \code{NA}'s.
}
\usage{
uniqueVec(oList, removeNA=FALSE)
}
\arguments{
  \item{oList}{The list from which duplicates will be removed. }
  \item{removeNA}{A boolean value, if \code{TRUE} then duplicates will
    be removed. }
}
\details{
  Not much to say, \code{unlist} then use \code{unique}. \code{NA}s are
  replaced with the string \code{NotMapped}.
}
\value{
   A vector containing the unique elements in the input list.
}
\author{E. Whalen and R. Gentleman}
\examples{
  xx<-list(a= 1:10, b=c(22,3,5))
  uniqueVec(xx) 
}
\keyword{ manip}

\eof
